#
# spec file for package calcurse
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           calcurse
Version:        4.8.1
Release:        1.4
Summary:        Text-based Organizer
License:        BSD-2-Clause
Group:          Productivity/Office/Organizers
URL:            https://calcurse.org
Source:         https://calcurse.org/files/%{name}-%{version}.tar.gz
Source1:        https://calcurse.org/files/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}.desktop
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files

%description
Calcurse is a text-based personal organizer which helps keep track of events
and everyday tasks. It has a calendar and a "todo" list, and puts your
appointments in order. The user interface is configurable, and you can choose
between different color schemes and layouts. All of the commands are
documented within an online help system.

%lang_package

%prep
%setup -q
sed -i "s/#!\/usr\/bin\/env python3/#!\/usr\/bin\/python3/" contrib/caldav/calcurse-caldav.py
sed -i "s/#!\/usr\/bin\/env python3/#!\/usr\/bin\/python3/" contrib/vdir/calcurse-vdir

%build
%configure
%make_build

%install
%make_install

rm -rf "%{buildroot}%{_datadir}/doc"

install -D -m 0644 %{SOURCE3} "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%if 0%{?suse_version}
%suse_update_desktop_file -r "%{name}" Office Calendar
%endif

mv "%{buildroot}%{_datadir}/locale/en" \
   "%{buildroot}%{_datadir}/locale/en_US"

%find_lang %{name}

%files
%license COPYING
%doc AUTHORS
%doc doc/manual.html
%{_bindir}/%{name}
%{_bindir}/%{name}-caldav
%{_bindir}/%{name}-upgrade
%{_bindir}/%{name}-vdir
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang

%changelog
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 4.8.1:
  * Fixed characters in weekly view.
  * Fixed import for iCal files with empty description
  * Fixed handling of note files edited outside calcurse
  * Fixed handling of recurrent open-ended appointments
  * Default description for items with empty descriptions
  * The PasswordCommand option can now be used to manage passwords
    in an external program and is the new recommended way of
    storing passwords for calcurse-caldav
* Thu Jul 21 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to version 4.8.0
  * New features:
  - Support any weekday as first day of week; previously, only Sunday and
    Monday were allowed.
  - Configuration of the format in which appointment time is displayed.
  - Actions without key bindings.
  - generic-prev-view key binding to cycle backwards through windows.
  - Support for Home/End keys in text input mode.
  * Bug fixes:
  - Support compilation on big-endian systems.
  - Fixed --docdir support.
  - Allow newlines in iCal SUMMARY by replacing them with blanks.
  - Fixed sidebar configuration sometimes not increasing width.
  - Layout change recognizes changed appointment space; before this change,
    a layout change did not update the maximum number of appointments visible
    until the config menu was left.
  * calcurse-caldav bug fixes:
  - Fixed InsecureSSL support.
* Wed Apr 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.7.1
  * Bug fixes:
  - Multiple iCal import fixes: Make iCal event import independent
    of property ordering. Return failure if an item is skipped.
    Avoid double free on import errors. Fix parsing of UNTIL.
  - Do not remove an empty note file after edit session.
  - Keep internal linked list sorted when moving items.
  - Prevent external hook/notification commands
    from interacting with the UI.
  * calcurse-caldav bug fixes:
  - Allow non-ASCII characters in username and password
  - Improved error handling for the configuration file.
    Unknown keys are now reported as errors instead of ignored.
  - Always request href from server after pushing a new object to prevent
    items from being erroneously deleted or created when path contains
    characters that need to be URL-encoded.
* Sun Feb  7 2021 Wang Jun <jgwang@suse.com>
- Update to version 4.7.0
  * Compatibility notes
  - Note file contents are now exported as DESCRIPTION in iCal exports
  - The item deletion menu has been redesigned
  - The systemdialogs option has been removed from the configuration
  * New features:
  - Support for advanced recurrence rules
  - Repeat counts are accepted in the UI as an alternative to repetition
    end dates for recurrent items
  - The :previous and :next commands can be used to jump to the previous/next
    occurrence of the currently selected recurrent item.
  - Various improvements in iCal imports
  - Notes are now displayed in the item view dialog
  * Bug fixes
  - Fixed formatting of DTSTART for recurrent events
  - Improvements in hook execution
  - Checks to make sure the config and data dirs exist
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.6.0:
  * XDG base directory support: While using ~/.calcurse/ is still supported for
  backwards compatibility, we recommend putting your configuration files in
  ~/.config/calcurse/ and your data files in ~/.local/share/calcurse/ instead
  (implemented by Nitroretro).
  * Configurable text for empty days
  * Support RET to set the todo item priority to 0
  * Various improvements in iCal imports
  * Escape necessary characters in SUMMARY on export (implemented by Kelvin Jackson).
  * Update notification bar properly when certain recurrent appointments are deleted (implemented by Lars Henriksen).
  * Fix save of interactively imported data (implemented by Lars Henriksen).
  * Restore ability to edit recurrent items without exceptions (reported and fixed by Lars Henriksen).
  * Fix monthly and yearly recurrence algorithms for frequencies greater than one (reported and fixed by Lars Henriksen).
  * Fix DST issues (reported by Lars Henriksen and others, fixed by Lars Henriksen).
* Tue Jun 18 2019 mvetter@suse.com
- Update to 4.5.0:
  Compatibility notes:
  * The --conf command line option has been renamed to --confdir and the --directory option has been renamed to --datadir.
  New features:
  * Multiple days support
  * Experimental vdir support: For details, refer to contrib/vdir/README.md in the calcurse source tree.
  * Support for editing recurrence exceptions (implemented by Lars Henriksen).
  New calcurse-caldav features:
  * Custom data directory support (implemented by vxid).
  * A new Troubleshooting section in the calcurse-caldav README.md (added by Randy Ramos).
  Bug fixes:
  * Various fixes in the notification system (implemented by Lars Henriksen).
  * Fix for a calendar redraw issue (implemented by Lars Henriksen).
  * Fix a potential deadlock (implemented by Lars Henriksen).
  * Use ICALDATETIMEFMT for EXDATE in iCal exports (implemented by Henrik Grimler).
  * Fix for the compile-time AsciiDoc check (implemented by Brandon Munger).
* Tue May 28 2019 mvetter@suse.com
- Update to 4.4.0:
  Compatibility notes:
  * The -F option is superseded by -P which can be used to remove certain entries from the data file (instead of keeping them). Please consult the man page for details.
  New features:
  * Major overhaul of the input routines in interactive mode (implemented by Lars Henriksen).
  * Support for separate data and configuration file directories (partly implemented by Quentin Hibon).
  * A --filter-invert option which inverts the other filter options (implemented by Lars Henriksen).
  * Support for negative date ranges when using the -d command line option.
  New calcurse-caldav features:
  * The SyncFilter configuration option which allows for specifying the types of items synced from/to the server (implemented by Satvik Sharma).
  * Support for a CALCURSE_CALDAV_PASSWORD environment variable which can be used to pass a password securely from another program (implemented by Randy Ramos).
  * HTTP support (implemented by Dino Macri).
  * Authorization removed from debug logs by default.
  Bug fixes:
  * Fix for an appointment becoming an event when entering an invalid start time (implemented by Lars Henriksen).
  * Fix for the deletion of a multi-day recurrent appointment (implemented by Lars Henriksen).
  * Fixes for potential database inconsistencies caused by appointments which end before they begin (implemented by Lars Henriksen).
  * Several fixes dealing with DST (implemented by Lars Henriksen).
  * Fixes for date range queries (implemented by Lars Henriksen).
  * Fix for segmentation fault with recent ncurses implementations.
  * Fix for potential segmentation fault in mutex handling.
  * RFC5545-compliant DTSTART in iCal exports (patch by Quentin Hibon).
  * Fix for not closing the stream after exporting iCal items (patch by crvs).
  * Fix for priority parsing in iCal imports (patch by dott).
  * Various improvements to the change detection and save conflict resolution code (implemented by Lars Henriksen).
  * Several improvements to concurrency control (implemented by Lars Henriksen).
  * Various fixes to the scrollbar (implemented by Lars Henriksen).
  * Various potential buffer overflow fixes.
  * A more robust command line argument parser (implemented by Lars Henriksen).
  * Various improvements to the UTF-8 handling code (implemented by Lars Henriksen).
  * Several stability and portability fixes (partly provided by Mikolaj Kucharski).
  * Several stability fixes in the calcurse-caldav script.
* Fri Jan 26 2018 avindra@opensuse.org
- Update to version 4.3.0
  * Compatibility notes:
  - Month names and abbreviated day names now honor the locale
    setting
  - The phase of moon feature was removed
  * New features:
  - The selected day in the calendar now stands out
  - Both the position and the date format used for the heading in
    the appointments panel are configurable
  - Support for CTRL-U and CTRL-G in prompts
  - Support for using all keys recognized by ncurses,
    particularly UTF-8 keys, in key bindings
  - Support for CALCURSE_EDITOR, CALCURSE_PAGER and
    CALCURSE_MERGETOOL environment variables to override the
    default editor, pager and merge tool
  - Several improvements to the reload and save routines. The
    save routine now detects external changes to the data files
    and no longer blindly overwrites data which was edited
    externally. In case of external changes, different options
    are offered, one of them being the execution of the merge
    tool to merge external changes and changes done from the
    running calcurse instance. The reload routine also no longer
    performs a reload if both the external data files and the
    local data are unchanged.
  - Several improvements to the CalDAV synchronization script,
    including OAuth2 support and instructions on how to
    synchronize calcurse with Google Calendar
  - Support for passing the password as a command-line argument
    to the CalDAV synchronization script
  - A new utility, called calcurse-dateutil, which can be used
    to create "extended recurrent events" such as events
    occurring on the third Thursday of each month
  * Bug Fixes:
  - Gracefully parse iCal parameters with colons
  - Fixes to the notification feature affecting recurrent
    appointments
  - Do not crash when changing colors
  - Avoid fatal error when using the help command
  - Avoid empty warning box when key is already in use
  - Several fixes to the calcurse-caldav synchronization script
    to allow for synchronizing with NextCloud servers
  - Proper support for punctual appointments starting at 00:00
  - Proper ISO 8601 week numbering
  - The delete key no longer acts as backspace
  - Proper parsing of date-time strings
- cleanup with spec-cleaner
- remove chmod line, no longer needed
* Thu Mar 23 2017 rpm@fthiessen.de
- Update to version 4.2.2
  * Prevent free-before-init of timstr
  * Prevent segfault when all todo items are hidden
  * Fix visible region after loading list box items
  * calcurse-caldav: Fix scrambled comment
- Added keyring and asc file for verification.
* Fri Oct 21 2016 p.drouand@gmail.com
- Update to version 4.2.0
  * In the calendar panel, days with non-recurrent items now have
    another color as days containing recurrent items only.
  * Automatically select new appointments/events after creation.
  * Support for (optional) dates when specifying the start/end time of items.
    Allows for easily moving items and adding appointments without switching
    the selected day beforehand.
  * Encoding fixes in calcurse-caldav
  * Avoid notification bar artifacts after leaving calcurse.
  * Fixes to the key binding pagination
  * Do not change selection unexpectedly after modifying items.
- Remove useless dependencies
  * autoconf
  * automake
  * gcc
  * gettext
  * make
* Wed Aug  3 2016 dmacvicar@suse.de
- Update to version 4.1.0
  * Hook support: Run scripts before/after loading or saving items. This
    feature can be used to automatically make Git commits or synchronize with a
    server when the data files are written. Example hooks can be found in the
    calcurse source tree.
  * Experimental CalDAV support: The calcurse distribution tarball now includes
    an experimental script called calcurse-caldav that can be used to
    synchronize calcurse with your mobile devices or any other computer. For
    details, please refer to contrib/caldav/README in the calcurse source tree.
  * Support for a filter mode -F that is identical to -G but writes the
    filtered items back to the calcurse data files instead of stdout. Can be
    used to remove certain items from a script. Use with care!
  * New long format specifiers "raw" and "hash".
  * A --daemon command line option to start calcurse in daemon mode.
  * A --quiet command line option to disable system dialogs.
  * Support for todo items with an undefined priority.
  * Support for durations when specifying recurrence end dates.
  * Support for decimal values when specifying durations.
  * Support for UTC times when importing iCal events.
  * Support for sending notifications for all appointments (both flagged and
    unflagged items).
  * The "Add Item" key binding now works from the calendar panel.
  * Week numbers in the monthly view (requested by Hakan Jerning).
  * Fixes to the slice computation (reported by Hakan Jerning).
  * Various fixes to the iCal import and export functionality.
* Tue Mar  3 2015 p.drouand@gmail.com
- Update to version 4.0.0
  * Support for reloading appointments via a key binding and via SIGUSR1
  * The compact mode and default panel options are no longer hidden.
  * A powerful set of new command line options. The new main operations in
    non-interactive mode are --grep and --query. There are filter switches to
    restrict the set of items that are read from the appointments file. All
    old command line options are still supported for backwards compatibility.
  * Support for shorthands such as "tomorrow" or "monday" as date specifiers.
  * Support for dates beyond 2038 on platforms with 64-bit time_t.
  * Several fixes to the user interface.
  * Handle CRLF line endings in iCal files
  * Gracefully handle all day events in iCal imports
  * Retain comments in descriptions and configuration values
  * Support all types of iCal durations
- Remove suse macros as calcurse doesn't build for other distributions
  anyway
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 3.2.1
  + Load todo items on startup
  + Do not highlight items on inactive windows.
- TODO file doesn't exist anymore; remove it from %%doc list
- Add COPYING file to %%doc list
* Mon Apr 22 2013 puzel@suse.com
- update to calcurse-3.1.4
  - Do not prompt for a todo after adding an appointment.
  - Close key binding window when reassigning the same key (thanks
    to Michael Smith for submitting a patch).
  - Update copyright ranges.
  - Do not ignore "--datarootdir" in the i18n Makefile.
  - Complete the test-suite even if libfaketime is not present.
  - Add a workaround for broken libfaketime-based tests on 32-bit
    systems (fixes Debian bug #697013).
  - Do not update start time/duration with bogus values if the
    prompt is canceled in edit mode.
  - Fix another corner case of the screen corruption bug (BUG#6).
  - Fix core dump when trying to edit a non-existent item.
  - Display correct welcome messages on startup.
* Sat Dec  8 2012 pascal.bleser@opensuse.org
- update to 3.1.1:
  * fix screen corruption bug
* Wed Dec  5 2012 pascal.bleser@opensuse.org
- update to 3.1.0:
  * Vim-like copy/paste (FR#15). Use the delete key to cut items.
  * Support for entering times in 24 hour format ("2130" instead of "21:30")
  * Compact panel mode (FR#7). This can be enabled using the currently
    undocumented "appearance.compactpanels" configuration setting.
  * Configurable default view (FR#19). The default view can be changed using
    the currently undocumented "appearance.defaultpanel" configuration setting.
  * "-D" and "-c" can now be used simultaneously, whereby "-c" has precedence
    over "-D".
  * Cache monthly view to speed up browsing.
  * Sort `calcurse -d` output by time
  * Fix a critical data corruption bug
  * Fix screen corruption
  * No longer show the calcurse screen in the editor/pager when the window is
    resized
  * Calculate busy slices correctly if (recurrent) appointments with a duration
    of more than 24 hours are used.
  * Fix a core dump that occurred if the main window was too small.
  * Several translation updates.
* Sun Jul  1 2012 pascal.bleser@opensuse.org
- update to 3.0.0:
  * full UTF-8 support
  * format strings for printing items in non-interactive mode have been
    introduced
  * support for vim-style count prefixes for displacement keys
  * duration strings are now much more powerful
  * extended duration strings, such as "+3:10" or "+1d20h5m", can be used
  * new feature allows piping items to external commands
  * there are keybindings to jump to the previous/next month/year
  * lots of internal changes have been made
  * note that you will need to run "calcurse-upgrade" after upgrading, since
    the configuration file format has changed
* Sun Jul  1 2012 puzel@suse.com
- update to calcurse-3.0.0
  - New features:
  - Full UTF-8 support.
  - Much more powerful formatting options for printing items in
    non-interactive mode. Format strings can be specified using
    "--format-apt", "--format-event", "--format-recur-apt" and
    "--format-recur-event".
  - Support for vim-style count prefixes for displacement keys.
  - Powerful duration strings: Allows using extended duration
    strings, such as "+3:10" or "+1d20h5m".
  - A feature that allows piping items to external commands.
  - New key bindings to jump to the previous/next month/year.
  - A new configuration file format. `calcurse-upgrade` can be used
    to convert existing configuration files.
  - Several performance improvements.
  - Notes are now stored using hash-based file names which results
    in lower disk space usage.
  - A test suite that can be used to test the core functionality of
    calcurse.
  - "-D" and "-c" can now be used simultaneously, whereby "-c" has
    precedence over "-D".
  - A "--read-only" command line option to discard all changes to
    data files.
  - Bug fixes:
  - Do not hardcode paths to the default editor/pager. Rely on the
    "$PATH" variable instead.
  - Update the number of todo items when importing an iCal file to
    prevent some items from being inaccessible.
  - Fix a segmentation fault when importing iCal data (reported by
    Andraz Levstik).
  - Format the "DURATION" field properly on iCal export. Use
    days/hours/minutes/seconds instead of seconds (reported and
    fixed by Jerome Pinot).
  - Do not localize dates in pcal exports (reported by Baptiste
    Jonglez).
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Sep 16 2011 puzel@suse.com
- update to 2.9.2
  - Handle iCal line folding correctly.
  - Introduce a configure option to completely exclude the
    documentation subdirectory from the build process
    ("--disable-docs").
- changes in 2.9.1
  - Keep the order of events across restarts (reported by Alan).
  - Fix the build process when disabling documentation generation.
  - Avoid flickering on window resize.
  - Avoid a segfault when resizing the calcurse window.
  - Add missing documentation for the "backword-kill-word" line
    editing function.
  - Honor the "TMPDIR" environment variable instead of using
    hardcoded paths for temporary files (reported by Erik Saule).
  - Fix pager invocation when showing the log file during an import
    (reported by Andraz Levstik).
  - Accept resource parameters in iCal import. Accept additional
    parameters such as language parameters (reported by Andraz
    Levstik).
  - Sync the notification item after editing or pasting an
    appointment. This ensures the information in the notification
    bar as well as the countdown for the notification daemon are
    always up-to-date (reported by Andraz Levstik).
  - Fix recurrent appointment notification.
  - Fix flagging of regular appointments.
  - Fix sort order when using command line options to display
    upcoming appointments and events (reported by Erik Saule).
* Sun May 29 2011 pascal.bleser@opensuse.org
- update to 2.9.0:
  * add support for short form dates
  * add "backword-kill-word" line editing function
  * add automatic removal of notes that are empty after editing
  * add a Russian translation
  * fixes a segfault when resizing the help window were fixed
  * fixes lock file issues
  * fixes parsing of appointment end times that date back
* Wed Jan 12 2011 puzel@novell.com
- minor spec cleanup (by Pascal)
* Sat Nov 13 2010 pascal.bleser@opensuse.org
- drop calcurse-fix_missing_return_in_nonvoid_function.patch, has been merged upstream
* Sun May 30 2010 pascal.bleser@opensuse.org
- update to 2.8:
  * adds a weekly calendar view that displays the week number and colored
    slices indicating appointment times
  * the side bar width can now be customized by the user
  * some bugs were addressed in this release, the most important being
    incorrect calculation of recurrent dates after a turn of year
* Sat Aug 29 2009 pascal.bleser@opensuse.org
- update to 2.7:
  * a daemon was implemented so that reminders can now be sent while calcurse
    is running in the background
  * a new '--status' command line option was added for displaying information
    about already running instances
  * important bugs related to ical import and export were addressed in this
    release
* Sun Jul 12 2009 pascal.bleser@opensuse.org
- update to 2.6
* Sat Dec 27 2008 guru@unixtech.be
- update to 2.4:
  * add ability to define its own key bindings.
  * the layout configuration menu was redesigned to become more user-friendly
  * important bugs were addressed in this release: a memory leak due to a
    wrong use of the pthread library was fixed, and a possible freeze when
    deleting an appointment's note does not appear anymore
  * regarding data export, exception dates are now properly ignored
  * a daylight saving time unwanted offset is not added anymore
* Wed Oct 15 2008 guru@unixtech.be
- update to 2.3:
  * adds the ability to import data from the iCalendar format as defined in
    RFC 2445
* Fri Aug 29 2008 guru@unixtech.be
- added Authors:
- update to 2.2:
  * add ability to export data to pcal format and thus to produce nice-looking
    Postscript output for printing
  * new command line arguments were added that allow you to use an alternative
    data directory, and to be more flexible when specifying the range of dates
    to be considered when displaying appointments and events
  * new key bindings ease movements in the calendar
- changes from 2.1:
  * fixed bug in changing of todo priority, which could result in a segfault
    in some cases
  * display note contents in non-interactive mode
  * date formats are now user-configurable
  * the Italian manual translation was added
* Sun Mar  2 2008 guru@unixtech.be
- new upstream version
* Wed Oct 24 2007 guru@unixtech.be
- moved to openSUSE Build Service
- new upstream version
* Sat Jan 20 2007 guru@unixtech.be
- new upstream version
* Sat Aug 26 2006 guru@unixtech.be
- new upstream version
* Tue May 30 2006 guru@unixtech.be
- new upstream version
* Sun Apr 23 2006 guru@unixtech.be
- new upstream version
- rewrote spec file
- pass -j to make
- removed Packager and Distribution, injected by rpmmacros
- binary stripping on SUSE < 9.3
